==> haskell-hls-qualify-imported-names-plugin-1.0.2.0-221-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-qualify-imported-names-plugin
version:              1.0.2.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-1.0.2.0-G637mMY8t2579QGAqU0ykv

key:
    hls-qualify-imported-names-plugin-1.0.2.0-G637mMY8t2579QGAqU0ykv

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8a2a1820823ca559e8737b30fc694200
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-1.0.2.0-G637mMY8t2579QGAqU0ykv

depends:
    aeson-2.1.2.1-GLiPeiAR7ZSFwx9H49aVEA base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    ghc-9.2.8 ghcide-1.10.0.0-C4QP9CvVIM076nXC3eqO6Z
    hls-graph-1.9.0.0-Ln446eHMli3Jn8E5Sosqko
    hls-plugin-api-1.6.0.0-6aAt33ROEfGFGKmYzVIAEM
    lsp-1.6.0.0-CTr572FCQofGXaNrrF5WCB text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-qualify-imported-names-plugin-1.0.2.0-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-qualify-imported-names-plugin
version:              1.0.2.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-1.0.2.0-EzMSSsu2ahc89oFDn7FfaS

key:
    hls-qualify-imported-names-plugin-1.0.2.0-EzMSSsu2ahc89oFDn7FfaS

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  63b9f28c4f6555923e92e196ae06cc61
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-qualify-imported-names-plugin-1.0.2.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-1.0.2.0-EzMSSsu2ahc89oFDn7FfaS

depends:
    aeson-2.1.2.1-GLiPeiAR7ZSFwx9H49aVEA base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    ghc-9.2.8 ghcide-1.10.0.0-1EmRaN29zOy1WiehU7ggQ6
    hls-graph-1.9.0.0-7QqrPUyZ0uJayRug0DY5p
    hls-plugin-api-1.6.0.0-2DR4541DY8a7Qydm6Fs7pB
    lsp-1.6.0.0-CTr572FCQofGXaNrrF5WCB text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
